mls.apiclient
*************

mls.apiclient is a Python client for the RESTful API of the `Propertyshelf MLS
<http://propertyshelf.com/>`_.

Installation
============

Use `pip` or `easy_install` to install the package::

    $ pip install mls.apiclient

Or install from the sources::

    $ tar xzf mls.apiclient-0.1.tgz
    $ cd mls.apiclient-0.1
    $ python setup.py install


Mostly Harmless
---------------

.. image:: https://travis-ci.org/propertyshelf/mls.apiclient.png?branch=master
   :target: http://travis-ci.org/propertyshelf/mls.apiclient
